"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.info = info;

var _rxjs = require("rxjs");

var _operators = require("rxjs/operators");

var _types = require("@polkadot/types");

var _drr = require("../util/drr");

var _chain = require("../chain");

// Copyright 2017-2019 @polkadot/api-derive authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
// internal helper to just split the logic - take all inputs, do the calculations and combine
function createDerived94(_ref) {
  let [bestNumber, [currentIndex, _lastLengthChange, sessionLength, lastEraLengthChange, sessionsPerEra]] = _ref;
  const lastLengthChange = _lastLengthChange && _lastLengthChange.unwrapOr(null) || (0, _types.createType)('BlockNumber');
  const sessionProgress = bestNumber.sub(lastLengthChange).add(sessionLength).mod(sessionLength);
  const currentEra = currentIndex.sub(lastEraLengthChange).mod(sessionsPerEra);
  const eraProgress = currentEra.mul(sessionLength).add(sessionProgress);
  return {
    currentEra: (0, _types.createType)('EraIndex', currentEra),
    currentIndex,
    eraLength: (0, _types.createType)('BlockNumber', sessionLength.mul(sessionsPerEra)),
    eraProgress: (0, _types.createType)('BlockNumber', eraProgress),
    isEpoch: false,
    lastEraLengthChange,
    lastLengthChange,
    sessionLength,
    sessionsPerEra,
    sessionProgress: (0, _types.createType)('BlockNumber', sessionProgress)
  };
}

function createDerivedLatest(_ref2) {
  let [[hasBabe, isGenesisSlot, epochDuration, sessionsPerEra], [currentSlot, epochIndex, epochOrGenesisStartSlot], [currentIndex, currentEra]] = _ref2;
  const epochStartSlot = isGenesisSlot ? epochIndex.mul(epochDuration).add(epochOrGenesisStartSlot) : epochOrGenesisStartSlot;
  const sessionProgress = currentSlot.sub(epochStartSlot);
  const eraProgress = epochIndex.mod(sessionsPerEra).mul(epochDuration).add(sessionProgress);
  return {
    currentEra,
    currentIndex,
    eraLength: (0, _types.createType)('BlockNumber', sessionsPerEra.mul(epochDuration)),
    eraProgress: (0, _types.createType)('BlockNumber', eraProgress),
    isEpoch: hasBabe,
    lastEraLengthChange: (0, _types.createType)('BlockNumber'),
    lastLengthChange: (0, _types.createType)('BlockNumber', epochStartSlot),
    sessionLength: epochDuration,
    sessionsPerEra,
    sessionProgress: (0, _types.createType)('BlockNumber', sessionProgress)
  };
}

function info94(api) {
  return (0, _rxjs.combineLatest)([(0, _chain.bestNumber)(api)(), api.queryMulti([api.query.session.currentIndex, api.query.session.lastLengthChange, api.query.session.sessionLength, api.query.staking.lastEraLengthChange, api.query.staking.sessionsPerEra])]).pipe((0, _operators.map)(createDerived94), (0, _drr.drr)());
}

function infoLatest(api) {
  const hasBabe = !!api.consts.babe;
  return (0, _rxjs.combineLatest)([(0, _rxjs.of)([hasBabe, hasBabe && !!api.query.babe.genesisSlot, hasBabe ? api.consts.babe.epochDuration : (0, _types.createType)('u64', 1), api.consts.staking.sessionsPerEra]), hasBabe ? api.queryMulti([api.query.babe.currentSlot, api.query.babe.epochIndex, api.query.babe.genesisSlot ? api.query.babe.genesisSlot : api.query.babe.epochStartSlot]) : (0, _rxjs.of)([(0, _types.createType)('u64', 1), (0, _types.createType)('u64', 1), (0, _types.createType)('u64', 1)]), api.queryMulti([api.query.session.currentIndex, api.query.staking.currentEra])]).pipe((0, _operators.map)(createDerivedLatest), (0, _drr.drr)());
}
/**
 * @description Retrieves all the session and era info and calculates specific values on it as the length of the session and eras
 */


function info(api) {
  return () => {
    // With substrate `spec_version 94`, the era and session has been explicitly exposed as `parameter_types`.
    // pre-94 we had more info and needed to calculate (handle old/Alex first)
    // https://github.com/paritytech/substrate/commit/dbf322620948935d2bbae214504e6c668c3073ed#diff-c29f42d6b931fa93ba038dbbbfec3055
    return api.query.session.lastLengthChange ? info94(api) // 1.x
    : infoLatest(api); // 2.x
  };
}